@@ -7,22 +7,21 @@
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
+#include <KIO/CopyJob>
 #include <KLocalizedString>
 #include <KMacroExpander>
 #include <KMessageBox>
 #include <KTar>
 #include <KZip>
-#include <KIO/CopyJob>
 
-#include <QTemporaryDir>
 #include <QDir>
 #include <QFileInfo>
-#include <QTextCodec>
+#include <QTemporaryDir>
 
-#include "kapptemplate.h"
 #include "generatepage.h"
-#include "prefs.h"
+#include "kapptemplate.h"
 #include "logging.h"
+#include "prefs.h"
 
 GeneratePage::GeneratePage(QWidget *parent)
     : QWizardPage(parent)
@@ -31,7 +30,7 @@ GeneratePage::GeneratePage(QWidget *parent)
     ui_generate.setupUi(this);
 }
 
-bool GeneratePage::unpackArchive(const KArchiveDirectory *dir, const QString &dest, const QStringList& skipList)
+bool GeneratePage::unpackArchive(const KArchiveDirectory *dir, const QString &dest, const QStringList &skipList)
 {
     qCDebug(KAPPTEMPLATE) << "unpacking dir:" << dir->name() << "to" << dest;
     const QStringList entries = dir->entries();
@@ -41,7 +40,7 @@ bool GeneratePage::unpackArchive(const KArchiveDirectory *dir, const QString &de
 
     bool ret = true;
 
-    //create path were we want copy files to
+    // create path were we want copy files to
     if (!QDir::root().mkpath(dest)) {
         displayError(i18n("%1 cannot be created.", dest));
         return false;
@@ -68,16 +67,17 @@ bool GeneratePage::unpackArchive(const KArchiveDirectory *dir, const QString &de
                 }
             }
             ret |= unpackArchive(file, newdest);
-        }
-        else if (dir->entry(entry)->isFile()) {
+        } else if (dir->entry(entry)->isFile()) {
             const KArchiveFile *file = dynamic_cast<const KArchiveFile *>(dir->entry(entry));
             file->copyTo(tdir.path());
             QString destName = KMacroExpander::expandMacros(dest + '/' + file->name(), m_variables);
             if (QFile(QDir::cleanPath(tdir.path() + '/' + file->name())).copy(destName)) {
                 if (!extractFileMacros(destName)) {
-                    displayError(i18n("Failed to integrate your project information into "
-                                      "the file %1. The project has not been generated and "
-                                      "all temporary files will be removed.", destName));
+                    displayError(
+                        i18n("Failed to integrate your project information into "
+                             "the file %1. The project has not been generated and "
+                             "all temporary files will be removed.",
+                             destName));
                     failed = true;
                     break;
                 }
@@ -100,11 +100,11 @@ bool GeneratePage::extractFileMacros(const QString &entry)
 {
     QString text;
     QFile file(entry);
-    if(file.exists() && file.open(QFile::ReadOnly)) {
+    if (file.exists() && file.open(QFile::ReadOnly)) {
         QTextStream input(&file);
         text = KMacroExpander::expandMacros(input.readAll(), m_variables);
         file.close();
-        if(file.open(QFile::WriteOnly | QIODevice::Truncate)) {
+        if (file.open(QFile::WriteOnly | QIODevice::Truncate)) {
             QTextStream output(&file);
             output << text;
             file.close();
@@ -124,7 +124,8 @@ void GeneratePage::initializePage()
     }
 
     QString archName;
-    const QStringList templatePaths = QStandardPaths::locateAll(QStandardPaths::GenericDataLocation, "/kdevappwizard/templates/", QStandardPaths::LocateDirectory);
+    const QStringList templatePaths =
+        QStandardPaths::locateAll(QStandardPaths::GenericDataLocation, "/kdevappwizard/templates/", QStandardPaths::LocateDirectory);
     for (const QString &templatePath : templatePaths) {
         const auto templateArchives = QDir(templatePath).entryList(QDir::Files);
         for (const QString &templateArchive : templateArchives) {
@@ -139,7 +140,7 @@ void GeneratePage::initializePage()
     if (archName.isEmpty())
         return;
 
-    //create dir where template project will be copied
+    // create dir where template project will be copied
     QString appName = field("appName").toString();
     QString version = field("version").toString();
 
@@ -164,8 +165,7 @@ void GeneratePage::initializePage()
     m_variables["APPNAMEFU"] = appName.replace(0, 1, appName.toUpper().at(0));
     m_variables["VERSIONCONTROLPLUGIN"] = QString(); // creation by kapptemplate is without VCS support/selection
 
-
-    KArchive* arch = nullptr;
+    KArchive *arch = nullptr;
     if (archName.endsWith(".zip")) {
         arch = new KZip(archName);
     } else {
@@ -177,12 +177,11 @@ void GeneratePage::initializePage()
         QStringList metaDataFileNames;
 
         // try by same name
-        const KArchiveEntry *templateEntry =
-            arch->directory()->entry(templateName + QLatin1String(".kdevtemplate"));
+        const KArchiveEntry *templateEntry = arch->directory()->entry(templateName + QLatin1String(".kdevtemplate"));
 
         // but could be different name, if e.g. downloaded, so make a guess
         if (!templateEntry || !templateEntry->isFile()) {
-            for (const auto& entryName : arch->directory()->entries()) {
+            for (const auto &entryName : arch->directory()->entries()) {
                 if (entryName.endsWith(QLatin1String(".kdevtemplate"))) {
                     templateEntry = arch->directory()->entry(entryName);
                     break;
@@ -194,14 +193,14 @@ void GeneratePage::initializePage()
             metaDataFileNames << templateEntry->name();
 
             // check if a preview file is to be ignored
-            const KArchiveFile *templateFile = static_cast<const KArchiveFile*>(templateEntry);
+            const KArchiveFile *templateFile = static_cast<const KArchiveFile *>(templateEntry);
             QTemporaryDir temporaryDir;
             templateFile->copyTo(temporaryDir.path());
 
             KConfig config(temporaryDir.path() + QLatin1Char('/') + templateEntry->name());
             KConfigGroup group(&config, "General");
             if (group.hasKey("Icon")) {
-                const KArchiveEntry* iconEntry = arch->directory()->entry(group.readEntry("Icon"));
+                const KArchiveEntry *iconEntry = arch->directory()->entry(group.readEntry("Icon"));
                 if (iconEntry && iconEntry->isFile()) {
                     metaDataFileNames << iconEntry->name();
                 }
@@ -224,7 +223,8 @@ void GeneratePage::initializePage()
     resume = i18n("Your project name is: <b>%1</b>, based on the %2 template.<br />", appName, templateName);
     resume.append(i18n("Version: %1 <br /><br />", version));
     resume.append(i18n("Installed in: %1 <br /><br />", url));
-    resume.append(i18n("You will find a README in your project folder <b>%1</b><br /> to help you get started with your project.", url + '/' + appName.toLower()));
+    resume.append(
+        i18n("You will find a README in your project folder <b>%1</b><br /> to help you get started with your project.", url + '/' + appName.toLower()));
     ui_generate.summaryLabel->setText(resume);
 }
 
@@ -234,3 +234,5 @@ void GeneratePage::displayError(const QString &error)
     feedback.append("\n\n" + error);
     ui_generate.label->setText(feedback);
 }
+
+#include "moc_generatepage.cpp"
